#
# spec file for package oath-toolkit
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           oath-toolkit
Version:        2.6.2
Release:        lp151.2.5
Summary:        Toolkit for one-time password authentication systems
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Networking/Security
URL:            http://www.nongnu.org/oath-toolkit/
Source:         http://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz
Patch1:         0001-Fix-no-return-in-nonvoid-function-errors-reported-by.patch
Patch2:         0002-update_gnulibs_files.patch
BuildRequires:  bison
BuildRequires:  gengetopt
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(xmlsec1)

%description
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package -n pam_oath
Summary:        PAM module for pluggable login authentication for OATH
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Security

%description -n pam_oath
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package -n     liboath0
Summary:        Library for Open AuTHentication (OATH) HOTP support
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Security
Requires:       %{name}-xml >= %{version}

%description -n liboath0
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package        xml
Summary:        This package contains xml files needed by liboath0
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description xml
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package -n     liboath-devel
Summary:        Library for Open AuTHentication (OATH) HOTP support -- Development Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       liboath0 = %{version}

%description -n liboath-devel
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package -n     libpskc0
Summary:        Library for Portable Symmetric Key Container
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Security

%description -n libpskc0
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%package -n     libpskc-devel
Summary:        Library for Portable Symmetric Key Container -- Development Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libpskc0 = %{version}

%description -n libpskc-devel
The OATH Toolkit makes it easy to build one-time password
authentication systems. It contains shared libraries, command line
tools and a PAM module. Supported technologies include the
event-based HOTP algorithm (RFC4226) and the time-based TOTP algorithm
(RFC6238). OATH stands for Open AuTHentication, which is the
organization that specify the algorithms. For managing secret key
files, the Portable Symmetric Key Container (PSKC) format described in
RFC6030 is supported.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
autoreconf -fiv
%configure  \
  --with-pam-dir=/%{_lib}/security \
  --with-libgcrypt \
  --disable-silent-rules \
  --with-pic \
  --disable-static
%make_build

%install
%make_install
mv COPYING COPYING.summary
find %{buildroot} -type f -name "*.la" -delete -print

%post -n liboath0 -p /sbin/ldconfig
%postun -n liboath0 -p /sbin/ldconfig
%post -n libpskc0 -p /sbin/ldconfig
%postun -n libpskc0 -p /sbin/ldconfig

%files
%license COPYING.summary
%doc ChangeLog NEWS README
%license oathtool/COPYING
%{_bindir}/oathtool
%{_mandir}/man1/oathtool.*
%{_bindir}/pskctool
%{_mandir}/man1/pskctool.*

%files -n pam_oath
%doc pam_oath/README
%license pam_oath/COPYING
/%{_lib}/security/pam_oath.so

%files -n liboath0
%license liboath/COPYING
%{_libdir}/liboath.so.*

%files xml
%{_datadir}/xml/pskc/

%files -n liboath-devel
%{_libdir}/liboath.so
%{_includedir}/liboath/
%{_libdir}/pkgconfig/liboath.pc
%doc %{_datadir}/gtk-doc/html/liboath
%{_mandir}/man3/oath_*

%files -n libpskc0
# there's no COPYING for libpskc, but it's LGPL, like liboath
%doc libpskc/README
%license liboath/COPYING
%{_libdir}/libpskc.so.*

%files -n libpskc-devel
%{_libdir}/libpskc.so
%{_includedir}/pskc/
%{_libdir}/pkgconfig/libpskc.pc
%doc %{_datadir}/gtk-doc/html/libpskc
%{_mandir}/man3/pskc_*

%changelog
* Fri Apr 13 2018 mpluskal@suse.com
- Run spe-cleaner
- Drop useless conditions
* Wed Apr 11 2018 ncutler@suse.com
- bring License line into closer accordance with actual licenses
  mentioned in the tarball
- split off xml/pskc/ directory/files from liboath0 into a separate
  "oath-toolkit-xml" subpackage to prevent conflicts if two versions of the
  liboath library were ever installed at the same time
* Wed Apr 11 2018 ncutler@suse.com
- use %%license instead of %%doc to package license-related files
* Tue Jan 16 2018 dmarcoux@posteo.de
- Add patch (last commit which changed source, not released in 2.6.2):
  - 0002-update_gnulibs_files.patch
* Mon Aug 29 2016 mardnh@gmx.de
- Update to Version 2.6.2
  - no changes in upstream code
- Fix RPM groups for -devel packages
- build with libpskc on supported suse-versions
- Add patch:
  - 0001-Fix-no-return-in-nonvoid-function-errors-reported-by.patch
* Wed Sep  9 2015 t.gruner@katodev.de
- Update to Version 2.6.1 (released 2015-07-31)
  - liboath: Fix 'make check' on 32-bit systems.
- Version 2.6.0 (released 2015-05-19)
  - liboath: Support TOTP with HMAC-SHA256 and HMAC-SHA512.
    This adds new APIs oath_totp_generate2, oath_totp_validate4 and
    oath_totp_validate4_callback.
  - oathtool: The --totp parameter now take an optional argument to specify MAC.
    For example use --totp=sha256 to use HMAC-SHA256.  When --totp is used
    the default HMAC-SHA1 is used, as before.
  - pam_oath: Mention in README that you shouldn't use insecure keys.
  - pam_oath: Check return value from strdup.
  - The files 'gdoc' and 'expect.oath' are now included in the tarball.
* Sat Jan 24 2015 mardnh@gmx.de
- Update to version 2.4.1:
  + liboath: Fix usersfile bug that caused it to update the wrong line.
    When an usersfile contain multiple lines for the same user but with an
    unparseable token type (e.g., HOTP vs TOTP), the code would update the
    wrong line of the file.  Since the then updated line could be a
    commented out line, this can lead to the same OTP being accepted
    multiple times which is a security vulnerability.  Reported by Bas van
    Schaik <bas@sj-vs.net> and patch provided by Ilkka Virta
    <itvirta@iki.fi>.  CVE-2013-7322
* Fri Jul 11 2014 darin@darins.net
- Ran through spec-cleaner
* Wed Oct 23 2013 vuntz@opensuse.org
- Update to version 2.4.0:
  + liboath: Add new API methods for validating TOTP OTPs
- Changes from version 2.2.0:
  + libpskc: Add functions for setting PSKC data.
  + liboath: Permit different passwords for different tokens for
    the same user.
  + liboath: Make header file usable from C++ (extern "C" guard).
  + build: Improve building from git with most recent automake and
    gengetopt.
  + build: Valgrind is not enabled by default.
- Fix license: libraries are LGPL-2.1+ and everything else is
  GPL-3.0+. Also properly package the COPYING files.
- Prepare build libpskc, hidden under a %%{build_pskc} define:
  + Add libxml2-devel and pkgconfig(xmlsec1) BuildRequires.
  + Create libpskc0 and libpskc-devel subpackages.
  + Define %%{build_pskc} to 0 since we don't have libxmlsec1 yet.
- Rework summaries and descriptions.
* Sat Jun 15 2013 bwiedemann@suse.com
- Update to version 2.0.2
* Fri Feb 11 2011 cristian.rodriguez@opensuse.org
- Update to version 1.4.6
* Sat Feb  5 2011 cristian.rodriguez@opensuse.org
- Use libgcrypt for crypto
* Sat Feb  5 2011 cristian.rodriguez@opensuse.org
- Initial version
